package com.lantone.daqe.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lantone.common.exception.Asserts;
import com.lantone.common.util.BeanUtil;
import com.lantone.common.util.StringUtil;
import com.lantone.daqe.dto.GetOperationPageDTO;
import com.lantone.daqe.entity.OperationInfo;
import com.lantone.daqe.facade.base.OperationInfoFacade;
import com.lantone.daqe.vo.AddOperationVO;
import com.lantone.daqe.vo.DelOperationByIdVO;
import com.lantone.daqe.vo.GetOperationPageVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Description: 手术管理-业务处理类
 * @author: rengb
 * @time: 2021/7/20 12:39
 */
@Component
public class OperationManagementFacade {

    @Autowired
    private OperationInfoFacade operationInfoFacade;

    public IPage<GetOperationPageDTO> getOperationPage(GetOperationPageVO getOperationPageVO) {
        Page<GetOperationPageDTO> getOperationPageDTOPage = new Page<>();

        QueryWrapper<OperationInfo> operationInfoQueryWrapper = new QueryWrapper<>();
        operationInfoQueryWrapper.eq(getOperationPageVO.getHospitalId() != null, "hospital_id", getOperationPageVO.getHospitalId());
        operationInfoQueryWrapper.like(StringUtil.isNotBlank(getOperationPageVO.getCode()), "code", getOperationPageVO.getCode());
        operationInfoQueryWrapper.like(StringUtil.isNotBlank(getOperationPageVO.getName()), "name", getOperationPageVO.getName());
        operationInfoQueryWrapper.like(StringUtil.isNotBlank(getOperationPageVO.getStandard()), "standard", getOperationPageVO.getStandard());
        if (StringUtil.isNotBlank(getOperationPageVO.getIsMapping())) {
            if (getOperationPageVO.getIsMapping().equals("0")) {
                operationInfoQueryWrapper.isNull("standard");
            } else if (getOperationPageVO.getIsMapping().equals("1")) {
                operationInfoQueryWrapper.isNotNull("standard");
            }
        }
        Page<OperationInfo> operationInfoPage = new Page<>(getOperationPageVO.getCurrent(), getOperationPageVO.getSize());
        operationInfoFacade.page(operationInfoPage, operationInfoQueryWrapper);
        BeanUtil.copyProperties(operationInfoPage, getOperationPageDTOPage);
        List<GetOperationPageDTO> getOperationPageDTOList = BeanUtil.listCopyTo(operationInfoPage.getRecords(), GetOperationPageDTO.class);
        getOperationPageDTOList.forEach(i -> {
            i.setIsMapping(StringUtil.isBlank(i.getIsMapping()) ? "未匹配" : "已匹配");
        });

        getOperationPageDTOPage.setRecords(getOperationPageDTOList);
        return getOperationPageDTOPage;
    }

    /**
     * 新增手术 业务处理
     *
     * @param addOperationVO
     * @return 是否新增成功
     */
    public boolean addOperation(AddOperationVO addOperationVO) {
        OperationInfo operationInfo = new OperationInfo();
        BeanUtil.copyProperties(addOperationVO, operationInfo);
        if (operationInfoFacade.isExist(operationInfo)) {
            Asserts.fail("该诊断已存在！");
        }
        return operationInfoFacade.save(operationInfo);
    }

    /**
     * 通过id删除手术
     *
     * @param delOperationByIdVO
     * @return 是否删除成功
     */
    public Boolean delOperationById(DelOperationByIdVO delOperationByIdVO) {
        if (operationInfoFacade.getById(delOperationByIdVO.getId()) == null) {
            Asserts.fail("该药品不存在！");
        }
        return operationInfoFacade.removeById(delOperationByIdVO.getId());
    }

}